@@ -1,34 +1,60 @@
 package WebService::Solr::Field;
 
-use Moose;
+use XML::Easy::Element;
+use XML::Easy::Content;
+use XML::Easy::Text ();
 
-has 'name' => ( is => 'rw', isa => 'Str' );
-
-has 'value' => ( is => 'rw', isa => 'Str' );
-
-has 'boost' => ( is => 'rw', isa => 'Maybe[Num]' );
-
-require XML::Generator;
-
-sub BUILDARGS {
-    my ( $self, $name, $value, $opts ) = @_;
+sub new {
+    my ( $class, $name, $value, $opts ) = @_;
     $opts ||= {};
 
-    return { name => $name, value => $value, %$opts };
+    die "name required"  unless defined $name;
+    die "value required" unless defined $value;
+
+    my $self = {
+        name  => $name,
+        value => $value,
+        %{ $opts },
+    };
+
+    return bless $self, $class;
+}
+
+sub name {
+    my $self = shift;
+    $self->{ name } = $_[ 0 ] if @_;
+    return $self->{ name };
+}
+
+sub value {
+    my $self = shift;
+    $self->{ value } = $_[ 0 ] if @_;
+    return $self->{ value };
+}
+
+sub boost {
+    my $self = shift;
+    $self->{ boost } = $_[ 0 ] if @_;
+    return $self->{ boost };
+}
+
+sub to_element {
+    my $self = shift;
+    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
+
+    return XML::Easy::Element->new(
+        'field',
+        { name => $self->name, %attr },
+        XML::Easy::Content->new( [ $self->value ] ),
+    );
 }
 
 sub to_xml {
     my $self = shift;
-    my $gen = XML::Generator->new( ':std', escape => 'always,even-entities' );
-    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
 
-    return $gen->field( { name => $self->name, %attr }, $self->value );
+    return XML::Easy::Text::xml10_write_element( $self->to_element );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -69,6 +95,10 @@ Creates a new field object. Currently, the only option available is a
 
 A Moose override to allow our custom constructor.
 
+=head2 to_element( )
+
+Serializes the object to an XML::Easy::Element object.
+
 =head2 to_xml( )
 
 Serializes the object to xml.
